@@ -7,7 +7,7 @@
 #
 #  Copyright  1996, Cees de Groot.
 #  Copyright  2000, Taketoshi Sano
-#  Copyright  2006-2015, Agustin Martin
+#  Copyright  2006-2018, Agustin Martin
 # --------------------------------------------------------------------------------
 
 package LinuxDocTools;
@@ -499,9 +499,10 @@ sub process_file {
 
   # Set common base name for temp files and temp file names
   my $tmpbase   = $global->{tmpbase} = $tmpdir . '/sgmltmp.' . $filename;
-  my $nsgmlsout = "$tmpbase.1";      # Was $tmpbase.1
-  my $preaspout = "$tmpbase.2";      # Was $tmpbase.2
-  my $aspout    = "$tmpbase.3";      # Was $tmpbase.3
+  my $precmdout = "$tmpbase.01.precmdout";
+  my $nsgmlsout = "$tmpbase.02.nsgmlsout";   # Was $tmpbase.1
+  my $preaspout = "$tmpbase.03.preaspout";   # Was $tmpbase.2
+  my $aspout    = "$tmpbase.04.aspout";      # Was $tmpbase.3
 
   # Set up the preprocessing command. Conditionals have to be
   # handled here until they can be moved into the DTD, otherwise
@@ -537,18 +538,25 @@ sub process_file {
       || die "$error_header: Could not open $global->{file} for reading. Aborting ...\n";
   }
 
-  open (my $WRITENSGMLS,
-	"$precmd | $main::progs->{NSGMLS} $global->{NsgmlsOpts} $ENV{SGMLDECL} > $nsgmlsout")
-    or die "$error_header: Could not open pipe to $nsgmlsout. Aborting ...\n";
+  # Create a temp file with $precmd output
+  my $precmd_command    = "$precmd > $precmdout";
+
+  open (my $PRECMDOUT, "$precmd_command")
+    or die "$error_header: Could not open pipe to $precmdout. Aborting ...\n";
 
   if ($global->{charset} eq "latin") {
-    print $WRITENSGMLS ldt_latin1tosgml($IFILE);
+    print $PRECMDOUT ldt_latin1tosgml($IFILE);
   } else {
-    copy($IFILE,$WRITENSGMLS);
+    copy($IFILE,$PRECMDOUT);
   }
 
   close $IFILE;
-  close $WRITENSGMLS;
+  close $PRECMDOUT;
+
+  # Process with nsgmls.
+  my $nsgmls_command = "$main::progs->{NSGMLS} $global->{NsgmlsOpts} $ENV{SGMLDECL} $precmdout > $nsgmlsout";
+  system($nsgmls_command) == 0
+    or die "Error: \"$nsgmls_command\" failed with exit status: ",$? >> 8,"\n";
 
   #  Special case: if format is global, we're just checking.
   cleanup if ( $global->{format} eq "global");
